@@ -1,5 +1,5 @@
 from collections import defaultdict
-from typing import Dict, List, Set  # noqa
+from typing import Dict, List, Set
 
 from django.conf import settings
 from django.contrib.auth.models import AnonymousUser
@@ -7,17 +7,16 @@ from django.contrib.contenttypes.fields import GenericForeignKey
 from django.contrib.contenttypes.models import ContentType
 from django.db import models, transaction
 from django.utils import timezone
-from django.utils.translation import ugettext as _
-from django.utils.translation import ugettext_lazy
 
 from openslides.core.config import config
-from openslides.core.models import Countdown, Projector
+from openslides.core.models import Countdown
 from openslides.utils.autoupdate import inform_changed_data
 from openslides.utils.exceptions import OpenSlidesError
 from openslides.utils.models import RESTModelMixin
 from openslides.utils.utils import to_roman
 
-from .access_permissions import ItemAccessPermissions
+from ..utils.models import CASCADE_AND_AUTOUPDATE, SET_NULL_AND_AUTOUPDATE
+from .access_permissions import ItemAccessPermissions, ListOfSpeakersAccessPermissions
 
 
 class ItemManager(models.Manager):
@@ -25,66 +24,58 @@ class ItemManager(models.Manager):
     Customized model manager with special methods for agenda tree and
     numbering.
     """
+
     def get_full_queryset(self):
         """
         Returns the normal queryset with all items. In the background all
-        speakers and related items (topics, motions, assignments) are
-        prefetched from the database.
+        related items (topics, motions, assignments) are prefetched from the database.
         """
-        return self.get_queryset().prefetch_related('speakers', 'content_object')
+        # TODO: Fix the django bug: we cannot include "content_object__agenda_items" here,
+        # because this is some kind of cyclic lookup. The _prefetched_objects_cache of every
+        # content object will hold wrong values for the agenda item.
+        # See issue #4738
+        return self.get_queryset().prefetch_related("content_object")
 
-    def get_only_agenda_items(self):
+    def get_only_non_public_items(self):
         """
-        Generator, which yields only agenda items. Skips hidden items.
+        Generator, which yields only internal and hidden items, that means only items
+        which type is INTERNAL_ITEM or HIDDEN_ITEM or which are children of hidden items.
         """
-        # Do not execute item.is_hidden() because this would create a lot of db queries
-        root_items, item_children = self.get_root_and_children(only_agenda_items=True)
+        # Do not execute non-hidden items because this would create a lot of db queries
+        root_items, item_children = self.get_root_and_children(only_item_type=None)
 
-        def yield_items(items):
+        def yield_items(items, parent_is_not_public=False):
             """
             Generator that yields a list of items and their children.
             """
             for item in items:
-                yield item
-                yield from yield_items(item_children[item.pk])
-
-        yield from yield_items(root_items)
-
-    def get_only_hidden_items(self):
-        """
-        Generator, which yields only hidden items, that means only items
-        which type is HIDDEN_ITEM or which are children of hidden items.
-        """
-        # Do not execute item.is_hidden() because this would create a lot of db queries
-        root_items, item_children = self.get_root_and_children(only_agenda_items=False)
-
-        def yield_items(items, parent_is_hidden=False):
-            """
-            Generator that yields a list of items and their children.
-            """
-            for item in items:
-                if parent_is_hidden or item.type == item.HIDDEN_ITEM:
-                    item_is_hidden = True
+                if parent_is_not_public or item.type in (
+                    item.INTERNAL_ITEM,
+                    item.HIDDEN_ITEM,
+                ):
+                    item_is_not_public = True
                     yield item
                 else:
-                    item_is_hidden = False
-                yield from yield_items(item_children[item.pk], parent_is_hidden=item_is_hidden)
+                    item_is_not_public = False
+                yield from yield_items(
+                    item_children[item.pk], parent_is_not_public=item_is_not_public
+                )
 
         yield from yield_items(root_items)
 
-    def get_root_and_children(self, only_agenda_items=False):
+    def get_root_and_children(self, only_item_type=None):
         """
         Returns a list with all root items and a dictonary where the key is an
         item pk and the value is a list with all children of the item.
 
-        If only_agenda_items is True, the tree hides items with type
-        HIDDEN_ITEM and all of their children.
+        If only_item_type is given, the tree hides items with other types and
+        all of their children.
         """
-        queryset = self.order_by('weight')
-        item_children = defaultdict(list)  # type: Dict[int, List[Item]]
+        queryset = self.order_by("weight")
+        item_children: Dict[int, List[Item]] = defaultdict(list)
         root_items = []
         for item in queryset:
-            if only_agenda_items and item.type == item.HIDDEN_ITEM:
+            if only_item_type is not None and item.type != only_item_type:
                 continue
             if item.parent_id is not None:
                 item_children[item.parent_id].append(item)
@@ -92,19 +83,21 @@ class ItemManager(models.Manager):
                 root_items.append(item)
         return root_items, item_children
 
-    def get_tree(self, only_agenda_items=False, include_content=False):
+    def get_tree(self, only_item_type=None, include_content=False):
         """
         Generator that yields dictonaries. Each dictonary has two keys, id
         and children, where id is the id of one agenda item and children is a
         generator that yields dictonaries like the one discribed.
 
-        If only_agenda_items is True, the tree hides items with type
-        HIDDEN_ITEM and all of their children.
+        If only_item_type is given, the tree hides items with other types and
+        all of their children.
 
         If include_content is True, the yielded dictonaries have no key 'id'
         but a key 'item' with the entire object.
         """
-        root_items, item_children = self.get_root_and_children(only_agenda_items=only_agenda_items)
+        root_items, item_children = self.get_root_and_children(
+            only_item_type=only_item_type
+        )
 
         def get_children(items):
             """
@@ -114,7 +107,9 @@ class ItemManager(models.Manager):
                 if include_content:
                     yield dict(item=item, children=get_children(item_children[item.pk]))
                 else:
-                    yield dict(id=item.pk, children=get_children(item_children[item.pk]))
+                    yield dict(
+                        id=item.pk, children=get_children(item_children[item.pk])
+                    )
 
         yield from get_children(root_items)
 
@@ -126,6 +121,7 @@ class ItemManager(models.Manager):
         The tree has to be a nested object. For example:
         [{"id": 1}, {"id": 2, "children": [{"id": 3}]}]
         """
+
         def walk_items(tree, parent=None):
             """
             Generator that returns each item in the tree as tuple.
@@ -134,21 +130,21 @@ class ItemManager(models.Manager):
             weight of the item.
             """
             for weight, element in enumerate(tree):
-                yield (element['id'], parent, weight)
-                yield from walk_items(element.get('children', []), element['id'])
+                yield (element["id"], parent, weight)
+                yield from walk_items(element.get("children", []), element["id"])
 
-        touched_items = set()  # type: Set[int]
+        touched_items: Set[int] = set()
         db_items = dict((item.pk, item) for item in Item.objects.all())
         for item_id, parent_id, weight in walk_items(tree):
             # Check that the item is only once in the tree to prevent invalid trees
             if item_id in touched_items:
-                raise ValueError("Item {} is more then once in the tree.".format(item_id))
+                raise ValueError(f"Item {item_id} is more then once in the tree.")
             touched_items.add(item_id)
 
             try:
                 db_item = db_items[item_id]
             except KeyError:
-                raise ValueError("Item {} is not in the database.".format(item_id))
+                raise ValueError(f"Item {item_id} is not in the database.")
 
             # Check if the item has changed and update it
             # Note: Do not use Item.objects.update, so that the items are sent
@@ -159,36 +155,37 @@ class ItemManager(models.Manager):
                 db_item.save()
 
     @transaction.atomic
-    def number_all(self, numeral_system='arabic'):
+    def number_all(self, numeral_system="arabic"):
         """
         Auto numbering of the agenda according to the numeral_system. Manually
         added item numbers will be overwritten.
         """
+
         def walk_tree(tree, number=None):
             for index, tree_element in enumerate(tree):
                 # Calculate number of visable agenda items.
-                if numeral_system == 'roman' and number is None:
+                if numeral_system == "roman" and number is None:
                     item_number = to_roman(index + 1)
                 else:
                     item_number = str(index + 1)
                     if number is not None:
-                        item_number = '.'.join((number, item_number))
+                        item_number = ".".join((number, item_number))
                 # Add prefix.
-                if config['agenda_number_prefix']:
-                    item_number_tmp = "%s %s" % (config['agenda_number_prefix'], item_number)
+                if config["agenda_number_prefix"]:
+                    item_number_tmp = f"{config['agenda_number_prefix']} {item_number}"
                 else:
                     item_number_tmp = item_number
                 # Save the new value and go down the tree.
-                tree_element['item'].item_number = item_number_tmp
-                tree_element['item'].save()
-                walk_tree(tree_element['children'], item_number)
+                tree_element["item"].item_number = item_number_tmp
+                tree_element["item"].save()
+                walk_tree(tree_element["children"], item_number)
 
         # Start numbering visable agenda items.
-        walk_tree(self.get_tree(only_agenda_items=True, include_content=True))
+        walk_tree(self.get_tree(only_item_type=Item.AGENDA_ITEM, include_content=True))
 
         # Reset number of hidden items.
-        for item in self.get_only_hidden_items():
-            item.item_number = ''
+        for item in self.get_only_non_public_items():
+            item.item_number = ""
             item.save()
 
 
@@ -196,15 +193,20 @@ class Item(RESTModelMixin, models.Model):
     """
     An Agenda Item
     """
+
     access_permissions = ItemAccessPermissions()
     objects = ItemManager()
+    can_see_permission = "agenda.can_see"
 
     AGENDA_ITEM = 1
-    HIDDEN_ITEM = 2
+    INTERNAL_ITEM = 2
+    HIDDEN_ITEM = 3
 
     ITEM_TYPE = (
-        (AGENDA_ITEM, ugettext_lazy('Agenda item')),
-        (HIDDEN_ITEM, ugettext_lazy('Hidden item')))
+        (AGENDA_ITEM, "Agenda item"),
+        (INTERNAL_ITEM, "Internal item"),
+        (HIDDEN_ITEM, "Hidden item"),
+    )
 
     item_number = models.CharField(blank=True, max_length=255)
     """
@@ -213,7 +215,7 @@ class Item(RESTModelMixin, models.Model):
 
     comment = models.TextField(null=True, blank=True)
     """
-    Optional comment to the agenda item. Will not be shoun to normal users.
+    Optional comment to the agenda item. Will not be shown to normal users.
     """
 
     closed = models.BooleanField(default=False)
@@ -221,9 +223,7 @@ class Item(RESTModelMixin, models.Model):
     Flag, if the item is finished.
     """
 
-    type = models.IntegerField(
-        choices=ITEM_TYPE,
-        default=HIDDEN_ITEM)
+    type = models.IntegerField(choices=ITEM_TYPE, default=HIDDEN_ITEM)
     """
     Type of the agenda item.
 
@@ -236,11 +236,12 @@ class Item(RESTModelMixin, models.Model):
     """
 
     parent = models.ForeignKey(
-        'self',
-        on_delete=models.SET_NULL,
+        "self",
+        on_delete=SET_NULL_AND_AUTOUPDATE,
         null=True,
         blank=True,
-        related_name='children')
+        related_name="children",
+    )
     """
     The parent item in the agenda tree.
     """
@@ -251,10 +252,8 @@ class Item(RESTModelMixin, models.Model):
     """
 
     content_type = models.ForeignKey(
-        ContentType,
-        on_delete=models.SET_NULL,
-        null=True,
-        blank=True)
+        ContentType, on_delete=models.SET_NULL, null=True, blank=True
+    )
     """
     Field for generic relation to a related object. Type of the object.
     """
@@ -269,56 +268,42 @@ class Item(RESTModelMixin, models.Model):
     Field for generic relation to a related object. General field to the related object.
     """
 
-    speaker_list_closed = models.BooleanField(
-        default=False)
-    """
-    True, if the list of speakers is closed.
-    """
-
     class Meta:
         default_permissions = ()
         permissions = (
-            ('can_see', 'Can see agenda'),
-            ('can_manage', 'Can manage agenda'),
-            ('can_manage_list_of_speakers', 'Can manage list of speakers'),
-            ('can_see_hidden_items', 'Can see hidden items and time scheduling of agenda'))
-        unique_together = ('content_type', 'object_id')
-
-    def __str__(self):
-        return self.title
-
-    def delete(self, skip_autoupdate=False, *args, **kwargs):
-        """
-        Customized method to delete an agenda item. Ensures that a respective
-        list of speakers projector element is disabled.
-        """
-        Projector.remove_any(
-            skip_autoupdate=skip_autoupdate,
-            name='agenda/list-of-speakers',
-            id=self.pk)
-        return super().delete(skip_autoupdate=skip_autoupdate, *args, **kwargs)  # type: ignore
+            ("can_see", "Can see agenda"),
+            ("can_manage", "Can manage agenda"),
+            (
+                "can_see_internal_items",
+                "Can see internal items and time scheduling of agenda",
+            ),
+        )
+        unique_together = ("content_type", "object_id")
+        ordering = ["weight"]
 
     @property
-    def title(self):
+    def title_information(self):
         """
-        Return get_agenda_title() from the content_object.
+        Return get_agenda_title_information() from the content_object.
         """
         try:
-            return self.content_object.get_agenda_title()
+            return self.content_object.get_agenda_title_information()
         except AttributeError:
-            raise NotImplementedError('You have to provide a get_agenda_title '
-                                      'method on your related model.')
+            raise NotImplementedError(
+                "You have to provide a get_agenda_title_information "
+                "method on your related model."
+            )
 
-    @property
-    def list_view_title(self):
+    def is_internal(self):
         """
-        Return get_agenda_list_view_title() from the content_object.
+        Returns True if the type of this object itself is a internal item or any
+        of its ancestors has such a type.
+
+        Attention! This executes one query for each ancestor of the item.
         """
-        try:
-            return self.content_object.get_agenda_list_view_title()
-        except AttributeError:
-            raise NotImplementedError('You have to provide a get_agenda_list_view_title '
-                                      'method on your related model.')
+        return self.type == self.INTERNAL_ITEM or (
+            self.parent is not None and self.parent.is_internal()
+        )
 
     def is_hidden(self):
         """
@@ -327,15 +312,95 @@ class Item(RESTModelMixin, models.Model):
 
         Attention! This executes one query for each ancestor of the item.
         """
-        return (self.type == self.HIDDEN_ITEM or
-                (self.parent is not None and self.parent.is_hidden()))
+        return self.type == self.HIDDEN_ITEM or (
+            self.parent is not None and self.parent.is_hidden()
+        )
+
+    @property
+    def level(self):
+        """
+        Returns the level in agenda (=tree of all items). Level 0 means this
+        item is a root item in the agenda. Level 1 indicates that the parent is
+        a root item, level 2 that the parent's parent is a root item and so on.
+
+        Attention! This executes one query for each ancestor of the item.
+        """
+        if self.parent is None:
+            return 0
+        else:
+            return self.parent.level + 1
+
+
+class ListOfSpeakersManager(models.Manager):
+    """
+    """
+
+    def get_full_queryset(self):
+        """
+        Returns the normal queryset with all items. In the background all
+        speakers and related items (topics, motions, assignments) are
+        prefetched from the database.
+        """
+        return self.get_queryset().prefetch_related("speakers", "content_object")
+
+
+class ListOfSpeakers(RESTModelMixin, models.Model):
+    """
+    """
+
+    access_permissions = ListOfSpeakersAccessPermissions()
+    objects = ListOfSpeakersManager()
+    can_see_permission = "agenda.can_see_list_of_speakers"
+
+    content_type = models.ForeignKey(
+        ContentType, on_delete=models.SET_NULL, null=True, blank=True
+    )
+    """
+    Field for generic relation to a related object. Type of the object.
+    """
+
+    object_id = models.PositiveIntegerField(null=True, blank=True)
+    """
+    Field for generic relation to a related object. Id of the object.
+    """
+
+    content_object = GenericForeignKey()
+    """
+    Field for generic relation to a related object. General field to the related object.
+    """
+
+    closed = models.BooleanField(default=False)
+    """
+    True, if the list of speakers is closed.
+    """
+
+    class Meta:
+        default_permissions = ()
+        permissions = (
+            ("can_see_list_of_speakers", "Can see list of speakers"),
+            ("can_manage_list_of_speakers", "Can manage list of speakers"),
+        )
+        unique_together = ("content_type", "object_id")
+
+    @property
+    def title_information(self):
+        """
+        Return get_list_of_speakers_title_information() from the content_object.
+        """
+        try:
+            return self.content_object.get_list_of_speakers_title_information()
+        except AttributeError:
+            raise NotImplementedError(
+                "You have to provide a get_list_of_speakers_title_information "
+                "method on your related model."
+            )
 
     def get_next_speaker(self):
         """
         Returns the speaker object of the speaker who is next.
         """
         try:
-            return self.speakers.filter(begin_time=None).order_by('weight')[0]
+            return self.speakers.filter(begin_time=None).order_by("weight")[0]
         except IndexError:
             # The list of speakers is empty.
             return None
@@ -345,21 +410,30 @@ class SpeakerManager(models.Manager):
     """
     Manager for Speaker model. Provides a customized add method.
     """
-    def add(self, user, item, skip_autoupdate=False):
+
+    def add(self, user, list_of_speakers, skip_autoupdate=False):
         """
         Customized manager method to prevent anonymous users to be on the
         list of speakers and that someone is twice on one list (off coming
         speakers). Cares also initial sorting of the coming speakers.
         """
-        if self.filter(user=user, item=item, begin_time=None).exists():
-            raise OpenSlidesError(
-                _('{user} is already on the list of speakers.').format(user=user))
+        if self.filter(
+            user=user, list_of_speakers=list_of_speakers, begin_time=None
+        ).exists():
+            raise OpenSlidesError(f"{user} is already on the list of speakers.")
         if isinstance(user, AnonymousUser):
-            raise OpenSlidesError(
-                _('An anonymous user can not be on lists of speakers.'))
-        weight = (self.filter(item=item).aggregate(
-            models.Max('weight'))['weight__max'] or 0)
-        speaker = self.model(item=item, user=user, weight=weight + 1)
+            raise OpenSlidesError("An anonymous user can not be on lists of speakers.")
+        if config["agenda_present_speakers_only"] and not user.is_present:
+            raise OpenSlidesError("Only present users can be on the lists of speakers.")
+        weight = (
+            self.filter(list_of_speakers=list_of_speakers).aggregate(
+                models.Max("weight")
+            )["weight__max"]
+            or 0
+        )
+        speaker = self.model(
+            list_of_speakers=list_of_speakers, user=user, weight=weight + 1
+        )
         speaker.save(force_insert=True, skip_autoupdate=skip_autoupdate)
         return speaker
 
@@ -371,19 +445,16 @@ class Speaker(RESTModelMixin, models.Model):
 
     objects = SpeakerManager()
 
-    user = models.ForeignKey(
-        settings.AUTH_USER_MODEL,
-        on_delete=models.CASCADE)
+    user = models.ForeignKey(settings.AUTH_USER_MODEL, on_delete=CASCADE_AND_AUTOUPDATE)
     """
     ForeinKey to the user who speaks.
     """
 
-    item = models.ForeignKey(
-        Item,
-        on_delete=models.CASCADE,
-        related_name='speakers')
+    list_of_speakers = models.ForeignKey(
+        ListOfSpeakers, on_delete=models.CASCADE, related_name="speakers"
+    )
     """
-    ForeinKey to the agenda item to which the user want to speak.
+    ForeinKey to the list of speakers to which the user want to speak.
     """
 
     begin_time = models.DateTimeField(null=True)
@@ -408,9 +479,7 @@ class Speaker(RESTModelMixin, models.Model):
 
     class Meta:
         default_permissions = ()
-        permissions = (
-            ('can_be_speaker', 'Can put oneself on the list of speakers'),
-        )
+        permissions = (("can_be_speaker", "Can put oneself on the list of speakers"),)
 
     def __str__(self):
         return str(self.user)
@@ -423,26 +492,38 @@ class Speaker(RESTModelMixin, models.Model):
         speaking, end his speech.
         """
         try:
-            current_speaker = (Speaker.objects.filter(item=self.item, end_time=None)
-                                              .exclude(begin_time=None).get())
+            current_speaker = (
+                Speaker.objects.filter(
+                    list_of_speakers=self.list_of_speakers, end_time=None
+                )
+                .exclude(begin_time=None)
+                .get()
+            )
         except Speaker.DoesNotExist:
             pass
         else:
-            # Do not send an autoupdate for the countdown and the item. This is done
-            # by saving the item and countdown later.
+            # Do not send an autoupdate for the countdown and the list_of_speakers. This is done
+            # by saving the list_of_speakers and countdown later.
             current_speaker.end_speech(skip_autoupdate=True)
         self.weight = None
         self.begin_time = timezone.now()
-        self.save()  # Here, the item is saved and causes an autoupdate.
-        if config['agenda_couple_countdown_and_speakers']:
-            countdown, created = Countdown.objects.get_or_create(pk=1, defaults={
-                'default_time': config['projector_default_countdown'],
-                'countdown_time': config['projector_default_countdown']})
+        self.save()  # Here, the list_of_speakers is saved and causes an autoupdate.
+        if config["agenda_couple_countdown_and_speakers"]:
+            countdown, created = Countdown.objects.get_or_create(
+                pk=1,
+                defaults={
+                    "default_time": config["projector_default_countdown"],
+                    "title": "Default countdown",
+                    "countdown_time": config["projector_default_countdown"],
+                },
+            )
             if not created:
-                countdown.control(action='reset', skip_autoupdate=True)
-            countdown.control(action='start', skip_autoupdate=True)
+                countdown.control(action="reset", skip_autoupdate=True)
+            countdown.control(action="start", skip_autoupdate=True)
 
-            inform_changed_data(countdown)  # Here, the autoupdate for the countdown is triggered.
+            inform_changed_data(
+                countdown
+            )  # Here, the autoupdate for the countdown is triggered.
 
     def end_speech(self, skip_autoupdate=False):
         """
@@ -450,16 +531,16 @@ class Speaker(RESTModelMixin, models.Model):
         """
         self.end_time = timezone.now()
         self.save(skip_autoupdate=skip_autoupdate)
-        if config['agenda_couple_countdown_and_speakers']:
+        if config["agenda_couple_countdown_and_speakers"]:
             try:
                 countdown = Countdown.objects.get(pk=1)
             except Countdown.DoesNotExist:
                 pass  # Do not create a new countdown on stop action
             else:
-                countdown.control(action='reset', skip_autoupdate=skip_autoupdate)
+                countdown.control(action="reset", skip_autoupdate=skip_autoupdate)
 
     def get_root_rest_element(self):
         """
-        Returns the item to this instance which is the root REST element.
+        Returns the list_of_speakers to this instance which is the root REST element.
         """
-        return self.item
+        return self.list_of_speakers
