@@ -1,6 +1,5 @@
 from django.contrib.auth import get_user_model
 from django.db import transaction
-from django.utils.translation import ugettext as _
 
 from openslides.utils.autoupdate import inform_changed_data
 from openslides.utils.rest_api import (
@@ -21,6 +20,7 @@ from .serializers import AssignmentAllPollSerializer
 
 # Viewsets for the REST API
 
+
 class AssignmentViewSet(ModelViewSet):
     """
     API endpoint for assignments.
@@ -29,6 +29,7 @@ class AssignmentViewSet(ModelViewSet):
     partial_update, update, destroy, candidature_self, candidature_other,
     mark_elected and create_poll.
     """
+
     access_permissions = AssignmentAccessPermissions()
     queryset = Assignment.objects.all()
 
@@ -36,26 +37,39 @@ class AssignmentViewSet(ModelViewSet):
         """
         Returns True if the user has required permissions.
         """
-        if self.action in ('list', 'retrieve'):
+        if self.action in ("list", "retrieve"):
             result = self.get_access_permissions().check_permissions(self.request.user)
-        elif self.action == 'metadata':
+        elif self.action == "metadata":
             # Everybody is allowed to see the metadata.
             result = True
-        elif self.action in ('create', 'partial_update', 'update', 'destroy',
-                             'mark_elected', 'create_poll', 'sort_related_users'):
-            result = (has_perm(self.request.user, 'assignments.can_see') and
-                      has_perm(self.request.user, 'assignments.can_manage'))
-        elif self.action == 'candidature_self':
-            result = (has_perm(self.request.user, 'assignments.can_see') and
-                      has_perm(self.request.user, 'assignments.can_nominate_self'))
-        elif self.action == 'candidature_other':
-            result = (has_perm(self.request.user, 'assignments.can_see') and
-                      has_perm(self.request.user, 'assignments.can_nominate_other'))
+        elif self.action in (
+            "create",
+            "partial_update",
+            "update",
+            "destroy",
+            "mark_elected",
+            "create_poll",
+            "sort_related_users",
+        ):
+            result = has_perm(self.request.user, "assignments.can_see") and has_perm(
+                self.request.user, "assignments.can_manage"
+            )
+        elif self.action == "candidature_self":
+            result = has_perm(self.request.user, "assignments.can_see") and has_perm(
+                self.request.user, "assignments.can_nominate_self"
+            )
+        elif self.action == "candidature_other":
+            result = has_perm(self.request.user, "assignments.can_see") and has_perm(
+                self.request.user, "assignments.can_nominate_other"
+            )
         else:
             result = False
         return result
 
-    @detail_route(methods=['post', 'delete'])
+    def perform_create(self, serializer):
+        serializer.save(request_user=self.request.user)
+
+    @detail_route(methods=["post", "delete"])
     def candidature_self(self, request, pk=None):
         """
         View to nominate self as candidate (POST) or withdraw own
@@ -63,18 +77,24 @@ class AssignmentViewSet(ModelViewSet):
         """
         assignment = self.get_object()
         if assignment.is_elected(request.user):
-            raise ValidationError({'detail': _('You are already elected.')})
-        if request.method == 'POST':
+            raise ValidationError({"detail": "You are already elected."})
+        if request.method == "POST":
             message = self.nominate_self(request, assignment)
         else:
             # request.method == 'DELETE'
             message = self.withdraw_self(request, assignment)
-        return Response({'detail': message})
+        return Response({"detail": message})
 
     def nominate_self(self, request, assignment):
         if assignment.phase == assignment.PHASE_FINISHED:
-            raise ValidationError({'detail': _('You can not candidate to this election because it is finished.')})
-        if assignment.phase == assignment.PHASE_VOTING and not has_perm(request.user, 'assignments.can_manage'):
+            raise ValidationError(
+                {
+                    "detail": "You can not candidate to this election because it is finished."
+                }
+            )
+        if assignment.phase == assignment.PHASE_VOTING and not has_perm(
+            request.user, "assignments.can_manage"
+        ):
             # To nominate self during voting you have to be a manager.
             self.permission_denied(request)
         # If the request.user is already a candidate he can nominate himself nevertheless.
@@ -82,19 +102,27 @@ class AssignmentViewSet(ModelViewSet):
         # Send new candidate via autoupdate because users without permission
         # to see users may not have it but can get it now.
         inform_changed_data([request.user])
-        return _('You were nominated successfully.')
+        return "You were nominated successfully."
 
     def withdraw_self(self, request, assignment):
         # Withdraw candidature.
         if assignment.phase == assignment.PHASE_FINISHED:
-            raise ValidationError({'detail': _('You can not withdraw your candidature to this election because it is finished.')})
-        if assignment.phase == assignment.PHASE_VOTING and not has_perm(request.user, 'assignments.can_manage'):
+            raise ValidationError(
+                {
+                    "detail": "You can not withdraw your candidature to this election because it is finished."
+                }
+            )
+        if assignment.phase == assignment.PHASE_VOTING and not has_perm(
+            request.user, "assignments.can_manage"
+        ):
             # To withdraw self during voting you have to be a manager.
             self.permission_denied(request)
         if not assignment.is_candidate(request.user):
-            raise ValidationError({'detail': _('You are not a candidate of this election.')})
+            raise ValidationError(
+                {"detail": "You are not a candidate of this election."}
+            )
         assignment.delete_related_user(request.user)
-        return _('You have withdrawn your candidature successfully.')
+        return "You have withdrawn your candidature successfully."
 
     def get_user_from_request_data(self, request):
         """
@@ -103,20 +131,28 @@ class AssignmentViewSet(ModelViewSet):
         self.mark_elected can play with it.
         """
         if not isinstance(request.data, dict):
-            detail = _('Invalid data. Expected dictionary, got %s.') % type(request.data)
-            raise ValidationError({'detail': detail})
-        user_str = request.data.get('user', '')
+            raise ValidationError(
+                {
+                    "detail": "Invalid data. Expected dictionary, got {0}.",
+                    "args": [type(request.data)],
+                }
+            )
+        user_str = request.data.get("user", "")
         try:
             user_pk = int(user_str)
         except ValueError:
-            raise ValidationError({'detail': _('Invalid data. Expected something like {"user": <id>}.')})
+            raise ValidationError(
+                {"detail": 'Invalid data. Expected something like {"user": <id>}.'}
+            )
         try:
             user = get_user_model().objects.get(pk=user_pk)
         except get_user_model().DoesNotExist:
-            raise ValidationError({'detail': _('Invalid data. User %d does not exist.') % user_pk})
+            raise ValidationError(
+                {"detail": "Invalid data. User {0} does not exist.", "args": [user_pk]}
+            )
         return user
 
-    @detail_route(methods=['post', 'delete'])
+    @detail_route(methods=["post", "delete"])
     def candidature_other(self, request, pk=None):
         """
         View to nominate other users (POST) or delete their candidature
@@ -124,43 +160,63 @@ class AssignmentViewSet(ModelViewSet):
         """
         user = self.get_user_from_request_data(request)
         assignment = self.get_object()
-        if request.method == 'POST':
-            message = self.nominate_other(request, user, assignment)
+        if request.method == "POST":
+            return self.nominate_other(request, user, assignment)
         else:
             # request.method == 'DELETE'
-            message = self.delete_other(request, user, assignment)
-        return Response({'detail': message})
+            return self.delete_other(request, user, assignment)
 
     def nominate_other(self, request, user, assignment):
         if assignment.is_elected(user):
-            raise ValidationError({'detail': _('User %s is already elected.') % user})
+            raise ValidationError(
+                {"detail": "User {0} is already elected.", "args": [str(user)]}
+            )
         if assignment.phase == assignment.PHASE_FINISHED:
-            detail = _('You can not nominate someone to this election because it is finished.')
-            raise ValidationError({'detail': detail})
-        if assignment.phase == assignment.PHASE_VOTING and not has_perm(request.user, 'assignments.can_manage'):
+            raise ValidationError(
+                {
+                    "detail": "You can not nominate someone to this election because it is finished."
+                }
+            )
+        if assignment.phase == assignment.PHASE_VOTING and not has_perm(
+            request.user, "assignments.can_manage"
+        ):
             # To nominate another user during voting you have to be a manager.
             self.permission_denied(request)
         if assignment.is_candidate(user):
-            raise ValidationError({'detail': _('User %s is already nominated.') % user})
+            raise ValidationError(
+                {"detail": "User {0} is already nominated.", "args": [str(user)]}
+            )
         assignment.set_candidate(user)
         # Send new candidate via autoupdate because users without permission
         # to see users may not have it but can get it now.
         inform_changed_data(user)
-        return _('User %s was nominated successfully.') % user
+        return Response(
+            {"detail": "User {0} was nominated successfully.", "args": [str(user)]}
+        )
 
     def delete_other(self, request, user, assignment):
         # To delete candidature status you have to be a manager.
-        if not has_perm(request.user, 'assignments.can_manage'):
+        if not has_perm(request.user, "assignments.can_manage"):
             self.permission_denied(request)
         if assignment.phase == assignment.PHASE_FINISHED:
-            detail = _("You can not delete someone's candidature to this election because it is finished.")
-            raise ValidationError({'detail': detail})
+            raise ValidationError(
+                {
+                    "detail": "You can not delete someone's candidature to this election because it is finished."
+                }
+            )
         if not assignment.is_candidate(user) and not assignment.is_elected(user):
-            raise ValidationError({'detail': _('User %s has no status in this election.') % user})
+            raise ValidationError(
+                {
+                    "detail": "User {0} has no status in this election.",
+                    "args": [str(user)],
+                }
+            )
         assignment.delete_related_user(user)
-        return _('Candidate %s was withdrawn successfully.') % user
+        return Response(
+            {"detail": "Candidate {0} was withdrawn successfully.", "args": [str(user)]}
+        )
 
-    @detail_route(methods=['post', 'delete'])
+    @detail_route(methods=["post", "delete"])
     def mark_elected(self, request, pk=None):
         """
         View to mark other users as elected (POST) or undo this (DELETE).
@@ -168,35 +224,46 @@ class AssignmentViewSet(ModelViewSet):
         """
         user = self.get_user_from_request_data(request)
         assignment = self.get_object()
-        if request.method == 'POST':
+        if request.method == "POST":
             if not assignment.is_candidate(user):
-                raise ValidationError({'detail': _('User %s is not a candidate of this election.') % user})
+                raise ValidationError(
+                    {
+                        "detail": "User {0} is not a candidate of this election.",
+                        "args": [str(user)],
+                    }
+                )
             assignment.set_elected(user)
-            message = _('User %s was successfully elected.') % user
+            message = "User {0} was successfully elected."
         else:
             # request.method == 'DELETE'
             if not assignment.is_elected(user):
-                detail = _('User %s is not an elected candidate of this election.') % user
-                raise ValidationError({'detail': detail})
+                raise ValidationError(
+                    {
+                        "detail": "User {0} is not an elected candidate of this election.",
+                        "args": [str(user)],
+                    }
+                )
             assignment.set_candidate(user)
-            message = _('User %s was successfully unelected.') % user
-        return Response({'detail': message})
+            message = "User {0} was successfully unelected."
+        return Response({"detail": message, "args": [str(user)]})
 
-    @detail_route(methods=['post'])
+    @detail_route(methods=["post"])
     def create_poll(self, request, pk=None):
         """
         View to create a poll. It is a POST request without any data.
         """
         assignment = self.get_object()
         if not assignment.candidates.exists():
-            raise ValidationError({'detail': _('Can not create ballot because there are no candidates.')})
+            raise ValidationError(
+                {"detail": "Can not create ballot because there are no candidates."}
+            )
         with transaction.atomic():
             poll = assignment.create_poll()
-        return Response({
-            'detail': _('Ballot created successfully.'),
-            'createdPollId': poll.pk})
+        return Response(
+            {"detail": "Ballot created successfully.", "createdPollId": poll.pk}
+        )
 
-    @detail_route(methods=['post'])
+    @detail_route(methods=["post"])
     def sort_related_users(self, request, pk=None):
         """
         Special view endpoint to sort the assignment related users.
@@ -206,22 +273,25 @@ class AssignmentViewSet(ModelViewSet):
         assignment = self.get_object()
 
         # Check data
-        related_user_ids = request.data.get('related_users')
+        related_user_ids = request.data.get("related_users")
         if not isinstance(related_user_ids, list):
-            raise ValidationError(
-                {'detail': _('users has to be a list of IDs.')})
+            raise ValidationError({"detail": "users has to be a list of IDs."})
 
         # Get all related users from AssignmentRelatedUser.
         related_users = {}
-        for related_user in AssignmentRelatedUser.objects.filter(assignment__id=assignment.id):
+        for related_user in AssignmentRelatedUser.objects.filter(
+            assignment__id=assignment.id
+        ):
             related_users[related_user.pk] = related_user
 
         # Check all given candidates from the request
         valid_related_users = []
         for related_user_id in related_user_ids:
-            if not isinstance(related_user_id, int) or related_users.get(related_user_id) is None:
-                raise ValidationError(
-                    {'detail': _('Invalid data.')})
+            if (
+                not isinstance(related_user_id, int)
+                or related_users.get(related_user_id) is None
+            ):
+                raise ValidationError({"detail": "Invalid data."})
             valid_related_users.append(related_users[related_user_id])
 
         # Sort the related users
@@ -236,7 +306,7 @@ class AssignmentViewSet(ModelViewSet):
         inform_changed_data(assignment)
 
         # Initiate response.
-        return Response({'detail': _('Assignment related users successfully sorted.')})
+        return Response({"detail": "Assignment related users successfully sorted."})
 
 
 class AssignmentPollViewSet(UpdateModelMixin, DestroyModelMixin, GenericViewSet):
@@ -245,6 +315,7 @@ class AssignmentPollViewSet(UpdateModelMixin, DestroyModelMixin, GenericViewSet)
 
     There are the following views: update, partial_update and destroy.
     """
+
     queryset = AssignmentPoll.objects.all()
     serializer_class = AssignmentAllPollSerializer
 
@@ -252,5 +323,6 @@ class AssignmentPollViewSet(UpdateModelMixin, DestroyModelMixin, GenericViewSet)
         """
         Returns True if the user has required permissions.
         """
-        return (has_perm(self.request.user, 'assignments.can_see') and
-                has_perm(self.request.user, 'assignments.can_manage'))
+        return has_perm(self.request.user, "assignments.can_see") and has_perm(
+            self.request.user, "assignments.can_manage"
+        )
