@@ -1,8 +1,5 @@
-import os
 import sys
-from collections import OrderedDict
-from operator import attrgetter
-from typing import Any, Dict, List
+from typing import Any, Dict
 
 from django.apps import AppConfig
 from django.conf import settings
@@ -95,9 +92,6 @@ class CoreAppConfig(AppConfig):
             self.get_model("Countdown").get_collection_string(), CountdownViewSet
         )
 
-        if "runserver" in sys.argv or "changeconfig" in sys.argv:
-            startup()
-
         # Register client messages
         register_client_message(NotifyWebsocketClientMessage())
         register_client_message(ConstantsWebsocketClientMessage())
@@ -106,6 +100,22 @@ class CoreAppConfig(AppConfig):
         register_client_message(ListenToProjectors())
         register_client_message(PingPong())
 
+        if "runserver" in sys.argv or "changeconfig" in sys.argv:
+            from openslides.utils.startup import run_startup_hooks
+
+            run_startup_hooks()
+
+    def get_startup_hooks(self):
+        from openslides.utils.constants import set_constants_from_apps
+        from openslides.utils.cache import element_cache
+        from openslides.core.models import History
+
+        return {
+            10: element_cache.ensure_schema_version,
+            40: set_constants_from_apps,
+            90: History.objects.build_history,
+        }
+
     def get_config_variables(self):
         from .config_variables import get_config_variables
 
@@ -127,8 +137,6 @@ class CoreAppConfig(AppConfig):
             yield self.get_model(model_name)
 
     def get_angular_constants(self):
-        from .config import config
-
         constants: Dict[str, Any] = {}
 
         # Client settings
@@ -147,34 +155,7 @@ class CoreAppConfig(AppConfig):
                 pass
         constants["Settings"] = client_settings_dict
 
-        # Config variables
-        config_groups: List[Any] = []
-        for config_variable in sorted(
-            config.config_variables.values(), key=attrgetter("weight")
-        ):
-            if config_variable.is_hidden():
-                # Skip hidden config variables. Do not even check groups and subgroups.
-                continue
-            if not config_groups or config_groups[-1]["name"] != config_variable.group:
-                # Add new group.
-                config_groups.append(
-                    OrderedDict(name=config_variable.group, subgroups=[])
-                )
-            if (
-                not config_groups[-1]["subgroups"]
-                or config_groups[-1]["subgroups"][-1]["name"]
-                != config_variable.subgroup
-            ):
-                # Add new subgroup.
-                config_groups[-1]["subgroups"].append(
-                    OrderedDict(name=config_variable.subgroup, items=[])
-                )
-            # Add the config variable to the current group and subgroup.
-            config_groups[-1]["subgroups"][-1]["items"].append(config_variable.data)
-        constants["ConfigVariables"] = config_groups
-
         constants["SchemaVersion"] = schema_version_handler.get()
-
         return constants
 
 
@@ -193,21 +174,3 @@ def manage_config(**kwargs):
     if altered:
         config.increment_version()
         logging.getLogger(__name__).info("Updated config variables")
-
-
-def startup():
-    """
-    Runs commands that are needed at startup.
-
-    Sets the cache, constants and startup history
-    """
-    if os.environ.get("NO_STARTUP"):
-        return
-
-    from openslides.utils.constants import set_constants, get_constants_from_apps
-    from openslides.utils.cache import element_cache
-    from openslides.core.models import History
-
-    element_cache.ensure_schema_version()
-    set_constants(get_constants_from_apps())
-    History.objects.build_history()
