@@ -308,7 +308,10 @@ class Motion(RESTModelMixin, AgendaItemWithListOfSpeakersMixin, models.Model):
                 # Identifier is already used.
                 if hasattr(self, "_identifier_prefix"):
                     # Calculate a new one and try again.
-                    self.identifier_number, self.identifier = self.increment_identifier_number(
+                    (
+                        self.identifier_number,
+                        self.identifier,
+                    ) = self.increment_identifier_number(
                         self.identifier_number, self._identifier_prefix
                     )
                 else:
@@ -408,7 +411,11 @@ class Motion(RESTModelMixin, AgendaItemWithListOfSpeakersMixin, models.Model):
     def is_submitter(self, user):
         """
         Returns True if user is a submitter of this motion, else False.
+        Anonymous users cannot be submitters.
         """
+        if isinstance(user, AnonymousUser):
+            return False
+
         return self.submitters.filter(user=user).exists()
 
     def is_supporter(self, user):
