@@ -4,7 +4,7 @@
  * For LGPL see License.txt in the project root for license information.
  * For commercial licenses see https://www.tiny.cloud/
  *
- * Version: 5.0.15 (2019-09-02)
+ * Version: 5.1.4 (2019-12-11)
  */
 (function (domGlobals) {
     'use strict';
@@ -85,37 +85,35 @@
       useQuickLink: useQuickLink
     };
 
-    var global$3 = tinymce.util.Tools.resolve('tinymce.dom.DOMUtils');
-
-    var global$4 = tinymce.util.Tools.resolve('tinymce.Env');
-
     var appendClickRemove = function (link, evt) {
       domGlobals.document.body.appendChild(link);
       link.dispatchEvent(evt);
       domGlobals.document.body.removeChild(link);
     };
     var open = function (url) {
-      if (!global$4.ie || global$4.ie > 10) {
-        var link = domGlobals.document.createElement('a');
-        link.target = '_blank';
-        link.href = url;
-        link.rel = 'noreferrer noopener';
-        var evt = domGlobals.document.createEvent('MouseEvents');
-        evt.initMouseEvent('click', true, true, domGlobals.window, 0, 0, 0, 0, 0, false, false, false, false, 0, null);
-        appendClickRemove(link, evt);
-      } else {
-        var win = domGlobals.window.open('', '_blank');
-        if (win) {
-          win.opener = null;
-          var doc = win.document;
-          doc.open();
-          doc.write('<meta http-equiv="refresh" content="0; url=' + global$3.DOM.encode(url) + '">');
-          doc.close();
-        }
-      }
+      var link = domGlobals.document.createElement('a');
+      link.target = '_blank';
+      link.href = url;
+      link.rel = 'noreferrer noopener';
+      var evt = domGlobals.document.createEvent('MouseEvents');
+      evt.initMouseEvent('click', true, true, domGlobals.window, 0, 0, 0, 0, 0, false, false, false, false, 0, null);
+      appendClickRemove(link, evt);
     };
     var OpenUrl = { open: open };
 
+    var __assign = function () {
+      __assign = Object.assign || function __assign(t) {
+        for (var s, i = 1, n = arguments.length; i < n; i++) {
+          s = arguments[i];
+          for (var p in s)
+            if (Object.prototype.hasOwnProperty.call(s, p))
+              t[p] = s[p];
+        }
+        return t;
+      };
+      return __assign.apply(this, arguments);
+    };
+
     var noop = function () {
     };
     var constant = function (value) {
@@ -126,8 +124,6 @@
     var never = constant(false);
     var always = constant(true);
 
-    var never$1 = never;
-    var always$1 = always;
     var none = function () {
       return NONE;
     };
@@ -141,37 +137,27 @@
       var id = function (n) {
         return n;
       };
-      var noop = function () {
-      };
-      var nul = function () {
-        return null;
-      };
-      var undef = function () {
-        return undefined;
-      };
       var me = {
         fold: function (n, s) {
           return n();
         },
-        is: never$1,
-        isSome: never$1,
-        isNone: always$1,
+        is: never,
+        isSome: never,
+        isNone: always,
         getOr: id,
         getOrThunk: call,
         getOrDie: function (msg) {
           throw new Error(msg || 'error: getOrDie called on none.');
         },
-        getOrNull: nul,
-        getOrUndefined: undef,
+        getOrNull: constant(null),
+        getOrUndefined: constant(undefined),
         or: id,
         orThunk: call,
         map: none,
-        ap: none,
         each: noop,
         bind: none,
-        flatten: none,
-        exists: never$1,
-        forall: always$1,
+        exists: never,
+        forall: always,
         filter: none,
         equals: eq,
         equals_: eq,
@@ -186,15 +172,10 @@
       return me;
     }();
     var some = function (a) {
-      var constant_a = function () {
-        return a;
-      };
+      var constant_a = constant(a);
       var self = function () {
         return me;
       };
-      var map = function (f) {
-        return some(f(a));
-      };
       var bind = function (f) {
         return f(a);
       };
@@ -205,8 +186,8 @@
         is: function (v) {
           return a === v;
         },
-        isSome: always$1,
-        isNone: never$1,
+        isSome: always,
+        isNone: never,
         getOr: constant_a,
         getOrThunk: constant_a,
         getOrDie: constant_a,
@@ -214,35 +195,31 @@
         getOrUndefined: constant_a,
         or: self,
         orThunk: self,
-        map: map,
-        ap: function (optfab) {
-          return optfab.fold(none, function (fab) {
-            return some(fab(a));
-          });
+        map: function (f) {
+          return some(f(a));
         },
         each: function (f) {
           f(a);
         },
         bind: bind,
-        flatten: constant_a,
         exists: bind,
         forall: bind,
         filter: function (f) {
           return f(a) ? me : NONE;
         },
-        equals: function (o) {
-          return o.is(a);
-        },
-        equals_: function (o, elementEq) {
-          return o.fold(never$1, function (b) {
-            return elementEq(a, b);
-          });
-        },
         toArray: function () {
           return [a];
         },
         toString: function () {
           return 'some(' + a + ')';
+        },
+        equals: function (o) {
+          return o.is(a);
+        },
+        equals_: function (o, elementEq) {
+          return o.fold(never, function (b) {
+            return elementEq(a, b);
+          });
         }
       };
       return me;
@@ -256,17 +233,12 @@
       from: from
     };
 
-    var slice = Array.prototype.slice;
-    var rawIndexOf = function () {
-      var pIndexOf = Array.prototype.indexOf;
-      var fastIndex = function (xs, x) {
-        return pIndexOf.call(xs, x);
-      };
-      var slowIndex = function (xs, x) {
-        return slowIndexOf(xs, x);
-      };
-      return pIndexOf === undefined ? slowIndex : fastIndex;
-    }();
+    var nativeSlice = Array.prototype.slice;
+    var nativeIndexOf = Array.prototype.indexOf;
+    var nativePush = Array.prototype.push;
+    var rawIndexOf = function (ts, t) {
+      return nativeIndexOf.call(ts, t);
+    };
     var contains = function (xs, x) {
       return rawIndexOf(xs, x) > -1;
     };
@@ -275,14 +247,14 @@
       var r = new Array(len);
       for (var i = 0; i < len; i++) {
         var x = xs[i];
-        r[i] = f(x, i, xs);
+        r[i] = f(x, i);
       }
       return r;
     };
     var each = function (xs, f) {
       for (var i = 0, len = xs.length; i < len; i++) {
         var x = xs[i];
-        f(x, i, xs);
+        f(x, i);
       }
     };
     var foldl = function (xs, f, acc) {
@@ -291,22 +263,13 @@
       });
       return acc;
     };
-    var slowIndexOf = function (xs, x) {
-      for (var i = 0, len = xs.length; i < len; ++i) {
-        if (xs[i] === x) {
-          return i;
-        }
-      }
-      return -1;
-    };
-    var push = Array.prototype.push;
     var flatten = function (xs) {
       var r = [];
       for (var i = 0, len = xs.length; i < len; ++i) {
         if (!isArray(xs[i])) {
           throw new Error('Arr.flatten item ' + i + ' was not an array, input: ' + xs);
         }
-        push.apply(r, xs[i]);
+        nativePush.apply(r, xs[i]);
       }
       return r;
     };
@@ -315,10 +278,10 @@
       return flatten(output);
     };
     var from$1 = isFunction(Array.from) ? Array.from : function (x) {
-      return slice.call(x);
+      return nativeSlice.call(x);
     };
 
-    var global$5 = tinymce.util.Tools.resolve('tinymce.util.Tools');
+    var global$3 = tinymce.util.Tools.resolve('tinymce.util.Tools');
 
     var hasProtocol = function (url) {
       return /^\w+:/i.test(url);
@@ -331,7 +294,7 @@
       var rules = ['noopener'];
       var rels = rel ? rel.split(/\s+/) : [];
       var toString = function (rels) {
-        return global$5.trim(rels.sort().join(' '));
+        return global$3.trim(rels.sort().join(' '));
       };
       var addTargetRules = function (rels) {
         rels = removeTargetRules(rels);
@@ -339,7 +302,7 @@
       };
       var removeTargetRules = function (rels) {
         return rels.filter(function (val) {
-          return global$5.inArray(rules, val) === -1;
+          return global$3.inArray(rules, val) === -1;
         });
       };
       var newRels = isUnsafe ? addTargetRules(rels) : removeTargetRules(rels);
@@ -364,7 +327,7 @@
       return elm && elm.nodeName === 'A' && !!elm.href;
     };
     var hasLinks = function (elements) {
-      return global$5.grep(elements, isLink).length > 0;
+      return global$3.grep(elements, isLink).length > 0;
     };
     var isOnlyTextSelected = function (html) {
       if (/</.test(html) && (!/^<a [^>]+>[^<]+<\/a>$/.test(html) || html.indexOf('href=') === -1)) {
@@ -394,6 +357,18 @@
       }
       return href;
     };
+    var applyLinkOverrides = function (editor, linkAttrs) {
+      var newLinkAttrs = __assign({}, linkAttrs);
+      if (!(Settings.getRelList(editor).length > 0) && Settings.allowUnsafeLinkTarget(editor) === false) {
+        var newRel = applyRelTargetRules(newLinkAttrs.rel, newLinkAttrs.target === '_blank');
+        newLinkAttrs.rel = newRel ? newRel : null;
+      }
+      if (Option.from(newLinkAttrs.target).isNone() && Settings.getTargetList(editor) === false) {
+        newLinkAttrs.target = Settings.getDefaultLinkTarget(editor);
+      }
+      newLinkAttrs.href = handleExternalTargets(newLinkAttrs.href, Settings.assumeExternalTargets(editor));
+      return newLinkAttrs;
+    };
     var updateLink = function (editor, anchorElm, text, linkAttrs) {
       text.each(function (text) {
         if (anchorElm.hasOwnProperty('innerText')) {
@@ -417,18 +392,10 @@
       }
     };
     var link = function (editor, attachState, data) {
+      var selectedElm = editor.selection.getNode();
+      var anchorElm = getAnchorElement(editor, selectedElm);
+      var linkAttrs = applyLinkOverrides(editor, getLinkAttrs(data));
       editor.undoManager.transact(function () {
-        var selectedElm = editor.selection.getNode();
-        var anchorElm = getAnchorElement(editor, selectedElm);
-        var linkAttrs = getLinkAttrs(data);
-        if (!(Settings.getRelList(editor).length > 0) && Settings.allowUnsafeLinkTarget(editor) === false) {
-          var newRel = applyRelTargetRules(linkAttrs.rel, linkAttrs.target === '_blank');
-          linkAttrs.rel = newRel ? newRel : null;
-        }
-        if (Option.from(linkAttrs.target).isNone()) {
-          linkAttrs.target = Settings.getDefaultLinkTarget(editor);
-        }
-        linkAttrs.href = handleExternalTargets(linkAttrs.href, Settings.assumeExternalTargets(editor));
         if (data.href === attachState.href) {
           attachState.attach();
         }
@@ -510,7 +477,7 @@
     };
     var sanitizeList = function (list, extractValue) {
       var out = [];
-      global$5.each(list, function (item) {
+      global$3.each(list, function (item) {
         var text = isString(item.text) ? item.text : isString(item.title) ? item.title : '';
         if (item.menu !== undefined) ; else {
           var value = extractValue(item);
@@ -638,19 +605,6 @@
       getDelta: getDelta
     };
 
-    var __assign = function () {
-      __assign = Object.assign || function __assign(t) {
-        for (var s, i = 1, n = arguments.length; i < n; i++) {
-          s = arguments[i];
-          for (var p in s)
-            if (Object.prototype.hasOwnProperty.call(s, p))
-              t[p] = s[p];
-        }
-        return t;
-      };
-      return __assign.apply(this, arguments);
-    };
-
     var exports$1 = {}, module = { exports: exports$1 };
     (function (define, exports, module, require) {
       (function (f) {
@@ -1266,11 +1220,11 @@
       pure: pure$1
     };
 
-    var global$6 = tinymce.util.Tools.resolve('tinymce.util.Delay');
+    var global$4 = tinymce.util.Tools.resolve('tinymce.util.Delay');
 
     var delayedConfirm = function (editor, message, callback) {
       var rng = editor.selection.getRng();
-      global$6.setEditorTimeout(editor, function () {
+      global$4.setEditorTimeout(editor, function () {
         editor.windowManager.confirm(message, function (state) {
           editor.selection.setRng(rng);
           callback(state);
@@ -1283,7 +1237,7 @@
       return suggestMailTo ? Option.some({
         message: 'The URL you entered seems to be an email address. Do you want to add the required mailto: prefix?',
         preprocess: function (oldData) {
-          return __assign({}, oldData, { href: 'mailto:' + url });
+          return __assign(__assign({}, oldData), { href: 'mailto:' + url });
         }
       }) : Option.none();
     };
@@ -1294,7 +1248,7 @@
         return suggestProtocol ? Option.some({
           message: 'The URL you entered seems to be an external link. Do you want to add the required http:// prefix?',
           preprocess: function (oldData) {
-            return __assign({}, oldData, { href: 'http://' + url });
+            return __assign(__assign({}, oldData), { href: 'http://' + url });
           }
         }) : Option.none();
       };
@@ -1342,7 +1296,7 @@
     };
     var ClassListOptions = { getClasses: getClasses };
 
-    var global$7 = tinymce.util.Tools.resolve('tinymce.util.XHR');
+    var global$5 = tinymce.util.Tools.resolve('tinymce.util.XHR');
 
     var parseJson = function (text) {
       try {
@@ -1358,7 +1312,7 @@
       var linkList = Settings.getLinkList(editor);
       return Future.nu(function (callback) {
         if (isString(linkList)) {
-          global$7.send({
+          global$5.send({
             url: linkList,
             success: function (text) {
               return callback(parseJson(text));
@@ -1723,6 +1677,12 @@
         onAction: Actions.openDialog(editor),
         onSetup: Actions.toggleActiveState(editor)
       });
+      editor.ui.registry.addButton('openlink', {
+        icon: 'new-tab',
+        tooltip: 'Open link',
+        onAction: Actions.gotoSelectedLink(editor),
+        onSetup: Actions.toggleEnabledState(editor)
+      });
       editor.ui.registry.addButton('unlink', {
         icon: 'unlink',
         tooltip: 'Remove link',
@@ -1755,8 +1715,8 @@
       });
     };
     var setupContextMenu = function (editor) {
-      var noLink = 'link';
       var inLink = 'link unlink openlink';
+      var noLink = 'link';
       editor.ui.registry.addContextMenu('link', {
         update: function (element) {
           return Utils.hasLinks(editor.dom.getParents(element, 'a')) ? inLink : noLink;
