@@ -4,7 +4,7 @@
  * For LGPL see License.txt in the project root for license information.
  * For commercial licenses see https://www.tiny.cloud/
  *
- * Version: 5.0.15 (2019-09-02)
+ * Version: 5.1.4 (2019-12-11)
  */
 (function (domGlobals) {
     'use strict';
@@ -103,6 +103,8 @@
     };
     var Commands = { register: register };
 
+    var noop = function () {
+    };
     var constant = function (value) {
       return function () {
         return value;
@@ -111,8 +113,6 @@
     var never = constant(false);
     var always = constant(true);
 
-    var never$1 = never;
-    var always$1 = always;
     var none = function () {
       return NONE;
     };
@@ -126,37 +126,27 @@
       var id = function (n) {
         return n;
       };
-      var noop = function () {
-      };
-      var nul = function () {
-        return null;
-      };
-      var undef = function () {
-        return undefined;
-      };
       var me = {
         fold: function (n, s) {
           return n();
         },
-        is: never$1,
-        isSome: never$1,
-        isNone: always$1,
+        is: never,
+        isSome: never,
+        isNone: always,
         getOr: id,
         getOrThunk: call,
         getOrDie: function (msg) {
           throw new Error(msg || 'error: getOrDie called on none.');
         },
-        getOrNull: nul,
-        getOrUndefined: undef,
+        getOrNull: constant(null),
+        getOrUndefined: constant(undefined),
         or: id,
         orThunk: call,
         map: none,
-        ap: none,
         each: noop,
         bind: none,
-        flatten: none,
-        exists: never$1,
-        forall: always$1,
+        exists: never,
+        forall: always,
         filter: none,
         equals: eq,
         equals_: eq,
@@ -171,15 +161,10 @@
       return me;
     }();
     var some = function (a) {
-      var constant_a = function () {
-        return a;
-      };
+      var constant_a = constant(a);
       var self = function () {
         return me;
       };
-      var map = function (f) {
-        return some(f(a));
-      };
       var bind = function (f) {
         return f(a);
       };
@@ -190,8 +175,8 @@
         is: function (v) {
           return a === v;
         },
-        isSome: always$1,
-        isNone: never$1,
+        isSome: always,
+        isNone: never,
         getOr: constant_a,
         getOrThunk: constant_a,
         getOrDie: constant_a,
@@ -199,35 +184,31 @@
         getOrUndefined: constant_a,
         or: self,
         orThunk: self,
-        map: map,
-        ap: function (optfab) {
-          return optfab.fold(none, function (fab) {
-            return some(fab(a));
-          });
+        map: function (f) {
+          return some(f(a));
         },
         each: function (f) {
           f(a);
         },
         bind: bind,
-        flatten: constant_a,
         exists: bind,
         forall: bind,
         filter: function (f) {
           return f(a) ? me : NONE;
         },
-        equals: function (o) {
-          return o.is(a);
-        },
-        equals_: function (o, elementEq) {
-          return o.fold(never$1, function (b) {
-            return elementEq(a, b);
-          });
-        },
         toArray: function () {
           return [a];
         },
         toString: function () {
           return 'some(' + a + ')';
+        },
+        equals: function (o) {
+          return o.is(a);
+        },
+        equals_: function (o, elementEq) {
+          return o.fold(never, function (b) {
+            return elementEq(a, b);
+          });
         }
       };
       return me;
@@ -261,27 +242,27 @@
     };
     var isFunction = isType('function');
 
-    var slice = Array.prototype.slice;
+    var nativeSlice = Array.prototype.slice;
     var map = function (xs, f) {
       var len = xs.length;
       var r = new Array(len);
       for (var i = 0; i < len; i++) {
         var x = xs[i];
-        r[i] = f(x, i, xs);
+        r[i] = f(x, i);
       }
       return r;
     };
     var each = function (xs, f) {
       for (var i = 0, len = xs.length; i < len; i++) {
         var x = xs[i];
-        f(x, i, xs);
+        f(x, i);
       }
     };
     var filter = function (xs, pred) {
       var r = [];
       for (var i = 0, len = xs.length; i < len; i++) {
         var x = xs[i];
-        if (pred(x, i, xs)) {
+        if (pred(x, i)) {
           r.push(x);
         }
       }
@@ -294,7 +275,7 @@
       return acc;
     };
     var from$1 = isFunction(Array.from) ? Array.from : function (x) {
-      return slice.call(x);
+      return nativeSlice.call(x);
     };
 
     var exports$1 = {}, module = { exports: exports$1 };
@@ -938,9 +919,8 @@
     var par$1 = function (futures) {
       return par(futures, Future.nu);
     };
-    var mapM = function (array, fn) {
-      var futures = map(array, fn);
-      return par$1(futures);
+    var traverse = function (array, fn) {
+      return par$1(map(array, fn));
     };
 
     var value = function () {
@@ -1041,11 +1021,11 @@
 
     var global$7 = tinymce.util.Tools.resolve('tinymce.html.DomParser');
 
-    var global$8 = tinymce.util.Tools.resolve('tinymce.html.Node');
+    var global$8 = tinymce.util.Tools.resolve('tinymce.html.Serializer');
 
-    var global$9 = tinymce.util.Tools.resolve('tinymce.html.Schema');
+    var global$9 = tinymce.util.Tools.resolve('tinymce.html.Node');
 
-    var global$a = tinymce.util.Tools.resolve('tinymce.html.Serializer');
+    var global$a = tinymce.util.Tools.resolve('tinymce.html.Schema');
 
     var shouldBlockDrop = function (editor) {
       return editor.getParam('paste_block_drop', false);
@@ -1118,7 +1098,7 @@
       return content;
     }
     function innerText(html) {
-      var schema = global$9();
+      var schema = global$a();
       var domParser = global$7({}, schema);
       var text = '';
       var shortEndedElements = schema.getShortEndedElements();
@@ -1278,7 +1258,7 @@
         }
         if (!currentListNode || currentListNode.name !== listName) {
           prevListNode = prevListNode || currentListNode;
-          currentListNode = new global$8(listName, 1);
+          currentListNode = new global$9(listName, 1);
           if (start > 1) {
             currentListNode.attr('start', '' + start);
           }
@@ -1390,11 +1370,11 @@
       });
       if (/(bold)/i.test(outputStyles['font-weight'])) {
         delete outputStyles['font-weight'];
-        node.wrap(new global$8('b', 1));
+        node.wrap(new global$9('b', 1));
       }
       if (/(italic)/i.test(outputStyles['font-style'])) {
         delete outputStyles['font-style'];
-        node.wrap(new global$8('i', 1));
+        node.wrap(new global$9('i', 1));
       }
       outputStyles = editor.dom.serializeStyle(outputStyles, node.name);
       if (outputStyles) {
@@ -1429,7 +1409,7 @@
         ]
       ]);
       var validElements = Settings.getWordValidElements(editor);
-      var schema = global$9({
+      var schema = global$a({
         valid_elements: validElements,
         valid_children: '-li[p]'
       });
@@ -1505,7 +1485,7 @@
       if (Settings.shouldConvertWordFakeLists(editor)) {
         convertFakeListsToProperLists(rootNode);
       }
-      content = global$a({ validate: editor.settings.validate }, schema).serialize(rootNode);
+      content = global$8({ validate: editor.settings.validate }, schema).serialize(rootNode);
       return content;
     };
     var preProcess = function (editor, content) {
@@ -1516,6 +1496,19 @@
       isWordContent: isWordContent
     };
 
+    var preProcess$1 = function (editor, html) {
+      var parser = global$7({}, editor.schema);
+      parser.addNodeFilter('meta', function (nodes) {
+        global$4.each(nodes, function (node) {
+          return node.remove();
+        });
+      });
+      var fragment = parser.parse(html, {
+        forced_root_block: false,
+        isRootContent: true
+      });
+      return global$8({ validate: editor.settings.validate }, editor.schema).serialize(fragment);
+    };
     var processResult = function (content, cancelled) {
       return {
         content: content,
@@ -1529,10 +1522,11 @@
     };
     var filterContent = function (editor, content, internal, isWordHtml) {
       var preProcessArgs = Events.firePastePreProcess(editor, content, internal, isWordHtml);
+      var filteredContent = preProcess$1(editor, preProcessArgs.content);
       if (editor.hasEventListeners('PastePostProcess') && !preProcessArgs.isDefaultPrevented()) {
-        return postProcessFilter(editor, preProcessArgs.content, internal, isWordHtml);
+        return postProcessFilter(editor, filteredContent, internal, isWordHtml);
       } else {
-        return processResult(preProcessArgs.content, preProcessArgs.isDefaultPrevented());
+        return processResult(filteredContent, preProcessArgs.isDefaultPrevented());
       }
     };
     var process = function (editor, html, internal) {
@@ -1542,15 +1536,8 @@
     };
     var ProcessFilters = { process: process };
 
-    var removeMeta = function (editor, html) {
-      var body = editor.dom.create('body', {}, html);
-      global$4.each(body.querySelectorAll('meta'), function (elm) {
-        return elm.parentNode.removeChild(elm);
-      });
-      return body.innerHTML;
-    };
     var pasteHtml = function (editor, html) {
-      editor.insertContent(removeMeta(editor, html), {
+      editor.insertContent(html, {
         merge: Settings.shouldMergeFormats(editor),
         paste: true
       });
@@ -1733,7 +1720,7 @@
       return event.type === 'paste';
     };
     var readBlobsAsDataUris = function (items) {
-      return mapM(items, function (item) {
+      return traverse(items, function (item) {
         return Future.nu(function (resolve) {
           var blob = item.getAsFile ? item.getAsFile() : item;
           var reader = new window.FileReader();
@@ -2064,7 +2051,7 @@
       };
     };
 
-    var noop = function () {
+    var noop$1 = function () {
     };
     var hasWorkingClipboardApi = function (clipboardData) {
       return global$2.iOS === false && clipboardData !== undefined && typeof clipboardData.setData === 'function' && Utils.isMsEdge() !== true;
@@ -2137,9 +2124,15 @@
       return function (evt) {
         if (hasSelectedContent(editor)) {
           setClipboardData(evt, getData(editor), fallback(editor), function () {
-            global$3.setTimeout(function () {
+            if (global$2.browser.isChrome()) {
+              var rng_1 = editor.selection.getRng();
+              global$3.setEditorTimeout(editor, function () {
+                editor.selection.setRng(rng_1);
+                editor.execCommand('Delete');
+              }, 0);
+            } else {
               editor.execCommand('Delete');
-            }, 0);
+            }
           });
         }
       };
@@ -2147,7 +2140,7 @@
     var copy = function (editor) {
       return function (evt) {
         if (hasSelectedContent(editor)) {
-          setClipboardData(evt, getData(editor), fallback(editor), noop);
+          setClipboardData(evt, getData(editor), fallback(editor), noop$1);
         }
       };
     };
