@@ -66,15 +66,6 @@ class ElementCacheProvider(Protocol):
     ) -> Tuple[Dict[str, List[bytes]], List[str]]:
         ...
 
-    async def set_lock(self, lock_name: str) -> bool:
-        ...
-
-    async def get_lock(self, lock_name: str) -> bool:
-        ...
-
-    async def del_lock(self, lock_name: str) -> None:
-        ...
-
     async def get_current_change_id(self) -> int:
         ...
 
@@ -250,7 +241,6 @@ class RedisCacheProvider:
     ) -> None:
         """
         Deletes the full_data_cache and write new data in it. Clears the change id key.
-        Does not clear locks.
         """
         async with get_connection() as redis:
             tr = redis.multi_exec()
@@ -266,7 +256,7 @@ class RedisCacheProvider:
         """
         Returns True, when there is data in the cache.
         """
-        async with get_connection() as redis:
+        async with get_connection(read_only=True) as redis:
             return await redis.exists(self.full_data_cache_key) and bool(
                 await redis.zrangebyscore(
                     self.change_id_cache_key, withscores=True, count=1, offset=0
@@ -279,7 +269,7 @@ class RedisCacheProvider:
         Returns all data from the full_data_cache in a mapping from element_id to the element.
         """
         return await aioredis.util.wait_make_dict(
-            self.eval("get_all_data", [self.full_data_cache_key])
+            self.eval("get_all_data", [self.full_data_cache_key], read_only=True)
         )
 
     @ensure_cache_wrapper()
@@ -289,7 +279,10 @@ class RedisCacheProvider:
         from element_id to the element.
         """
         response = await self.eval(
-            "get_collection_data", [self.full_data_cache_key], [f"{collection}:*"]
+            "get_collection_data",
+            [self.full_data_cache_key],
+            [f"{collection}:*"],
+            read_only=True,
         )
 
         collection_data = {}
@@ -305,7 +298,7 @@ class RedisCacheProvider:
         Returns one element from the cache. Returns None, when the element does not exist.
         """
         return await self.eval(
-            "get_element_data", [self.full_data_cache_key], [element_id]
+            "get_element_data", [self.full_data_cache_key], [element_id], read_only=True
         )
 
     @ensure_cache_wrapper()
@@ -356,6 +349,7 @@ class RedisCacheProvider:
                 "get_data_since",
                 keys=[self.full_data_cache_key, self.change_id_cache_key],
                 args=[change_id, redis_max_change_id],
+                read_only=True,
             )
         )
 
@@ -371,36 +365,12 @@ class RedisCacheProvider:
                 changed_elements[collection_string].append(element_json)
         return changed_elements, deleted_elements
 
-    async def set_lock(self, lock_name: str) -> bool:
-        """
-        Tries to sets a lock.
-
-        Returns True when the lock could be set and False, if it was already set.
-        """
-        # TODO: Improve lock. See: https://redis.io/topics/distlock
-        async with get_connection() as redis:
-            return await redis.setnx(f"lock_{lock_name}", 1)
-
-    async def get_lock(self, lock_name: str) -> bool:
-        """
-        Returns True, when the lock is set. Else False.
-        """
-        async with get_connection() as redis:
-            return await redis.get(f"lock_{lock_name}")
-
-    async def del_lock(self, lock_name: str) -> None:
-        """
-        Deletes the lock. Does nothing when the lock is not set.
-        """
-        async with get_connection() as redis:
-            await redis.delete(f"lock_{lock_name}")
-
     @ensure_cache_wrapper()
     async def get_current_change_id(self) -> int:
         """
         Get the highest change_id from redis.
         """
-        async with get_connection() as redis:
+        async with get_connection(read_only=True) as redis:
             value = await redis.zrevrangebyscore(
                 self.change_id_cache_key, withscores=True, count=1, offset=0
             )
@@ -414,7 +384,7 @@ class RedisCacheProvider:
         """
         Get the lowest change_id from redis.
         """
-        async with get_connection() as redis:
+        async with get_connection(read_only=True) as redis:
             value = await redis.zscore(
                 self.change_id_cache_key, "_config:lowest_change_id"
             )
@@ -424,7 +394,7 @@ class RedisCacheProvider:
 
     async def get_schema_version(self) -> Optional[SchemaVersion]:
         """ Retrieves the schema version of the cache or None, if not existent """
-        async with get_connection() as redis:
+        async with get_connection(read_only=True) as redis:
             schema_version = await redis.hgetall(self.schema_cache_key)
         if not schema_version:
             return None
@@ -441,7 +411,11 @@ class RedisCacheProvider:
             await redis.hmset_dict(self.schema_cache_key, schema_version)
 
     async def eval(
-        self, script_name: str, keys: List[str] = [], args: List[Any] = []
+        self,
+        script_name: str,
+        keys: List[str] = [],
+        args: List[Any] = [],
+        read_only: bool = False,
     ) -> Any:
         """
         Runs a lua script in redis. This wrapper around redis.eval tries to make
@@ -459,7 +433,7 @@ class RedisCacheProvider:
                 "A script with a ensure_cache prefix must have the full_data cache key as its first key"
             )
 
-        async with get_connection() as redis:
+        async with get_connection(read_only=read_only) as redis:
             try:
                 return await redis.evalsha(hash, keys, args)
             except aioredis.errors.ReplyError as e:
@@ -585,21 +559,6 @@ class MemoryCacheProvider:
                 changed_elements[collection_string].append(element_json.encode())
         return changed_elements, deleted_elements
 
-    async def set_lock(self, lock_name: str) -> bool:
-        if lock_name in self.locks:
-            return False
-        self.locks[lock_name] = "1"
-        return True
-
-    async def get_lock(self, lock_name: str) -> bool:
-        return lock_name in self.locks
-
-    async def del_lock(self, lock_name: str) -> None:
-        try:
-            del self.locks[lock_name]
-        except KeyError:
-            pass
-
     async def get_current_change_id(self) -> int:
         if self.change_id_data:
             return max(self.change_id_data.keys())
